#!/bin/sh

TARGET=$1
PREFIX=$2
SWPKG=$3

SWURL="svn://svn.code.sf.net/p/avarice/code/trunk"
MODULE="avarice"
REVISION="346"

SW="avarice-$REVISION.tar.bz2"


if test -z "$PREFIX"; then
    echo "Crosscompiler install script."
    echo "To install the target toolchain type the following command:"
    echo $0 " <TargetAch> <InstallDir> <SoftwarePackage>"
    echo
    echo "The software package can be one of these:"
    echo "[all] binutils minimal-gcc uclibc gcc gdb make avarice clean"
    echo "If the parameter is missing, we're taking [all] as default."
    exit 0
fi

echo "We're going to install avarice in this directory: " $PREFIX
echo "for " $TARGET " Architecture"
echo

# the different paths
FILEDIR=`pwd`
SRCDIR=$PREFIX/src
BUILDDIR=$SRCDIR/build

# The tar archievs
AVARICE=`ls $DOWNLOADDIR/$SW`

if [[ $AVARICE = $DOWNLOADDIR/$SW ]];
then
    echo $AVARICE " already found"
else
    echo $TOOLSDIR/checkout.sh $MODULE $SWURL $REVISION
    $TOOLSDIR/checkout.sh $MODULE $SWURL $REVISION || exit 1

    echo cd $DOWNLOADDIR
    cd $DOWNLOADDIR || exit 1

    echo mv $FILEDIR/$SW $DOWNLOADDIR/$SW
    mv $FILEDIR/$SW $DOWNLOADDIR/$SW || exit 1

    AVARICE=$DOWNLOADDIR/$SW
fi

# 0. creating the directory
echo mkdir -p $SRCDIR
mkdir -p $SRCDIR || exit 1


# 1. setting the path
PATH=$PATH:$PREFIX/bin

# 2. avarice
case $SWPKG in

    avarice | all | tools)

    echo tar -xj -C $SRCDIR -f $AVARICE
    tar -xj -C $SRCDIR -f $AVARICE || exit 1

    AVARICESRCDIR=`ls -d $SRCDIR/avarice*`

    echo cd $AVARICESRCDIR
    cd $AVARICESRCDIR || exit 1

    echo ./Bootstrap
    ./Bootstrap || exit 1

    echo sed -e 's@#error config.h must be included before this header@//#error config.h must be included before this header@' -i $PREFIX/x86_64-unknown-linux-gnu/avr/include/bfd.h
    sed -e 's@#error config.h must be included before this header@//#error config.h must be included before this header@' -i $PREFIX/x86_64-unknown-linux-gnu/avr/include/bfd.h || exit 1

    echo mkdir -p $BUILDDIR/avarice
    mkdir -p $BUILDDIR/avarice || exit 1

    echo cd $BUILDDIR/avarice
    cd $BUILDDIR/avarice || exit 1

    export CPPFLAGS="-I$PREFIX/x86_64-unknown-linux-gnu/avr/include"

    export CFLAGS=""

    export LDFLAGS="-static -L$PREFIX/x86_64-unknown-linux-gnu/avr/lib"

    echo $AVARICESRCDIR/configure --enable-target-programming --build=x86_64-unknown-linux-gnu --host=$HOST --prefix=$PREFIX || exit 1
    $AVARICESRCDIR/configure --enable-target-programming --build=x86_64-unknown-linux-gnu --host=$HOST --prefix=$PREFIX || exit 1

    echo make -j 3
    make -j 3 || exit 1

    echo make install 
    make install || exit 1

    echo rm -rf $BUILDDIR/avarice $AVARICESRCDIR
    rm -rf $BUILDDIR/avarice $AVARICESRCDIR || exit 1

    cd $FILEDIR || exit 1

    ;;

    canadian-avarice | canadian-all | canadian-tools)

    echo tar -xj -C $SRCDIR -f $AVARICE
    tar -xj -C $SRCDIR -f $AVARICE || exit 1

    AVARICESRCDIR=`ls -d $SRCDIR/avarice*`

    echo cd $AVARICESRCDIR
    cd $AVARICESRCDIR || exit 1

    echo ./Bootstrap
    ./Bootstrap || exit 1

    echo sed -e 's@#error config.h must be included before this header@//#error config.h must be included before this header@' -i $PREFIX/x86_64-unknown-linux-gnu/avr/include/bfd.h
    sed -e 's@#error config.h must be included before this header@//#error config.h must be included before this header@' -i $PREFIX/x86_64-unknown-linux-gnu/avr/include/bfd.h || exit 1

    echo mkdir -p $BUILDDIR/avarice
    mkdir -p $BUILDDIR/avarice || exit 1

    echo cd $BUILDDIR/avarice
    cd $BUILDDIR/avarice || exit 1

	# Installed cygwin is necessary (on gentoo: crossdev -t i686-pc-cygwin)
    export HOST=i686-pc-cygwin

    export AR=$HOST-ar
    export AS=$HOST-as
    export CC=$HOST-gcc
    export LD=$HOST-ld
    export NM=$HOST-nm
    export RANLIB=$HOST-ranlib
    export CPPFLAGS="-I$PREFIX/$HOST/avr/include -I$SRCDIR/libusb-win32-bin-1.2.6.0/include"
    export CFLAGS=$CPPFLAGS
    export LDFLAGS="-static -L$PREFIX/$HOST/avr/lib -L$SRCDIR/libusb-win32-bin-1.2.6.0/lib/gcc"

    echo $AVARICESRCDIR/configure --enable-target-programming --build=x86_64-unknown-linux-gnu --host=$HOST --prefix=$PREFIX || exit 1
    $AVARICESRCDIR/configure --enable-target-programming --build=x86_64-unknown-linux-gnu --host=$HOST --prefix=$PREFIX || exit 1

    echo make -j 3
    make -j 3 || exit 1

    echo make install 
    make install || exit 1

    echo rm -rf $BUILDDIR/avarice $AVARICESRCDIR
    rm -rf $BUILDDIR/avarice $AVARICESRCDIR || exit 1

    cd $FILEDIR || exit 1

    ;;

esac

exit 0
