#!/bin/sh

TARGET=$1
PREFIX=$2
SWPKG=$3

SWURL="svn://svn.savannah.nongnu.org/avrdude/trunk"
MODULE="avrdude"
REVISION="1338"

SW="avrdude-$REVISION.tar.bz2"

if test -z "$PREFIX"; then
    echo "Crosscompiler install script."
    echo "To install the target toolchain type the following command:"
    echo $0 " <TargetAch> <InstallDir> <SoftwarePackage>"
    echo
    echo "The software package can be one of these:"
    echo "[all] binutils minimal-gcc uclibc gcc gdb make avarice avrdude clean"
    echo "If the parameter is missing, we're taking [all] as default."
    exit 0
fi

echo "We're going to install avrdude in this directory: " $PREFIX
echo "for " $TARGET " Architecture"
echo

# the different paths
FILEDIR=`pwd`
SRCDIR=$PREFIX/src
BUILDDIR=$SRCDIR/build

# The tar archievs
AVRDUDE=`ls $DOWNLOADDIR/$SW`

if [[ $AVRDUDE = $DOWNLOADDIR/$SW ]];
then
    echo $AVRDUDE " already found"
else
    echo $TOOLSDIR/checkout.sh $MODULE $SWURL $REVISION
    $TOOLSDIR/checkout.sh $MODULE $SWURL $REVISION || exit 1

    echo cd $DOWNLOADDIR
    cd $DOWNLOADDIR || exit 1

    echo mv $FILEDIR/$SW $DOWNLOADDIR/$SW
    mv $FILEDIR/$SW $DOWNLOADDIR/$SW || exit 1

    AVRDUDE=$DOWNLOADDIR/$SW
fi

# 0. creating the directory
echo mkdir -p $SRCDIR
mkdir -p $SRCDIR || exit 1


# 1. setting the path
PATH=$PATH:$PREFIX/bin


# 2. avrdude
case $SWPKG in

    avrdude)

    echo tar -xj -C $SRCDIR -f $AVRDUDE
    tar -xj -C $SRCDIR -f $AVRDUDE || exit 1

    AVRDUDESRCDIR=`ls -d $SRCDIR/avrdude*`

    echo cd $AVRDUDESRCDIR
    cd $AVRDUDESRCDIR || exit 1

    echo ./bootstrap
    ./bootstrap || exit 1

#
#

    echo mkdir -p $BUILDDIR/avrdude
    mkdir -p $BUILDDIR/avrdude || exit 1

    echo cd $BUILDDIR/avrdude
    cd $BUILDDIR/avrdude || exit 1

    echo $AVRDUDESRCDIR/configure --prefix=$PREFIX
    $AVRDUDESRCDIR/configure --prefix=$PREFIX || exit 1

    echo make -j 3
    make -j 3 || exit 1

    echo make install 
    make install || exit 1

    echo rm -rf $BUILDDIR/avrdude $AVRDUDESRCDIR
    rm -rf $BUILDDIR/avrdude $AVRDUDESRCDIR || exit 1

    cd $FILEDIR || exit 1

    ;;

    canadian-avrdude)

    echo tar -xj -C $SRCDIR -f $AVRDUDE
    tar -xj -C $SRCDIR -f $AVRDUDE || exit 1

    AVRDUDESRCDIR=`ls -d $SRCDIR/avrdude*`

    echo cd $AVRDUDESRCDIR
    cd $AVRDUDESRCDIR || exit 1

    echo ./bootstrap
    ./bootstrap || exit 1

    echo mkdir -p $BUILDDIR/avrdude
    mkdir -p $BUILDDIR/avrdude || exit 1

    echo cd $BUILDDIR/avrdude
    cd $BUILDDIR/avrdude || exit 1

    export HOST=i686-w64-mingw32

    export AR=$HOST-ar
    export AS=$HOST-as
    export CC=$HOST-gcc
    export LD=$HOST-ld
    export NM=$HOST-nm
    export RANLIB=$HOST-ranlib

    export CPPFLAGS="-I$PREFIX/x86_64-unknown-linux-gnu/avr/include -I$SRCDIR/libusb-win32-bin-1.2.6.0/include"

    export CFLAGS=$CPPFLAGS

    export LDFLAGS="-static -L$PREFIX/x86_64-unknown-linux-gnu/avr/lib -L$SRCDIR/libusb-win32-bin-1.2.6.0/lib/gcc"

    echo $AVRDUDESRCDIR/configure --build=x86_64-unknown-linux-gnu --host=$HOST --prefix=$PREFIX
    $AVRDUDESRCDIR/configure --build=x86_64-unknown-linux-gnu --host=$HOST --prefix=$PREFIX || exit 1

    echo make -j 3
    make -j 3 || exit 1

    echo make install 
    make install || exit 1

    echo rm -rf $BUILDDIR/avrdude $AVRDUDESRCDIR
    rm -rf $BUILDDIR/avrdude $AVRDUDESRCDIR || exit 1

    cd $FILEDIR || exit 1

    ;;

esac

exit 0
