#!/bin/sh

TARGET=$1
PREFIX=$2
SWPKG=$3

SWURL="svn://svn.savannah.nongnu.org/avr-libc/trunk"
MODULE="avr-libc"
#REVISION="2454"
REVISION="2474"

SW="avr-libc-$REVISION.tar.bz2"

if test -z "$PREFIX"; then
    echo "Crosscompiler install script."
    echo "To install the target toolchain type the following command:"
    echo $0 " <TargetAch> <InstallDir> <SoftwarePackage>"
    echo
    echo "The software package can be one of these:"
    echo "[all] binutils minimal-gcc uclibc gcc gdb clean"
    echo "If the parameter is missing, we're taking [all] as default."
    exit 0
fi

echo "We're going to install the avr-libc in this directory: " $PREFIX
echo "for " $TARGET " Architecture"
echo

# the different paths
FILEDIR=`pwd`
SRCDIR=$PREFIX/src
BUILDDIR=$SRCDIR/build

# The tar archievs
LIBC=`ls $DOWNLOADDIR/$SW`

if [[ $LIBC = $DOWNLOADDIR/$SW ]];
then
    echo $LIBC " already found"
else
    echo $TOOLSDIR/checkout.sh $MODULE $SWURL $REVISION
    $TOOLSDIR/checkout.sh $MODULE $SWURL $REVISION || exit 1

    echo cd $DOWNLOADDIR
    cd $DOWNLOADDIR || exit 1

    echo mv $FILEDIR/$SW $DOWNLOADDIR/$SW
    mv $FILEDIR/$SW $DOWNLOADDIR/$SW || exit 1

    LIBC=$DOWNLOADDIR/$SW
fi


# 0. creating the directory
echo mkdir -p $SRCDIR
mkdir -p $SRCDIR || exit 1


# 1. setting the path
PATH=$PREFIX/bin:$PATH


# 2. Do it ...
case $SWPKG in

    canadian-libc | libc)

    echo tar -xj -C $SRCDIR -f $LIBC
    tar -xj -C $SRCDIR -f $LIBC || exit 1

    LIBCSRCDIR=`ls -d $SRCDIR/avr-lib*`

    echo cd $LIBCSRCDIR
    cd $LIBCSRCDIR || exit 1

    echo ./bootstrap
    ./bootstrap || exit 1

    echo mkdir -p $BUILDDIR/avr-libc
    mkdir -p $BUILDDIR/avr-libc || exit 1

    echo cd $BUILDDIR/avr-libc
    cd $BUILDDIR/avr-libc || exit 1

    export AR=avr-ar
    export AS=avr-as
    export CC=avr-gcc
    export LD=avr-ld
    export NM=avr-nm
    export RANLIB=avr-ranlib

    echo $LIBCSRCDIR/configure --build=$TARGET --prefix=$PREFIX
    $LIBCSRCDIR/configure --build=$TARGET --prefix=$PREFIX || exit 1

    echo make
    make -j 3 || exit 1

    echo make install
    make install || exit 1

    echo rm -rf $BUILDDIR/avr-libc $LIBCSRCDIR
    rm -rf $BUILDDIR/avr-libc $LIBCSRCDIR || exit 1

    echo rm -rf $PREFIX-minimal
    rm -rf $PREFIX-minimal || exit 1

    cd $FILEDIR || exit 1

    ;;

esac


exit 0
