#!/bin/sh

TARGET=$1
PREFIX=$2
SWPKG=$3

SWURL="http://ftp.gnu.org/gnu/binutils/"
SW="binutils-2.25.tar.bz2"

if test -z "$PREFIX"; then
    echo "Crosscompiler install script."
    echo "To install the target toolchain type the following command:"
    echo $0 " <TargetAch> <InstallDir> <SoftwarePackage>"
    echo
    echo "The software package can be one of these:"
    echo "[all] binutils minimal-gcc libc gcc gdb clean"
    echo "If the parameter is missing, we're taking [all] as default."
    exit 0
fi

echo "We're going to install the binutils in this directory: " $PREFIX
echo "for " $TARGET " Architecture"
echo

# the different paths
FILEDIR=`pwd`
SRCDIR=$PREFIX/src
BUILDDIR=$SRCDIR/build

# The tar archievs
BINUTILS=`ls $DOWNLOADDIR/$SW`

if [[ $BINUTILS = $DOWNLOADDIR/$SW ]];
then
    echo $BINUTILS " already found"
else
    echo cd $DOWNLOADDIR
    cd $DOWNLOADDIR || exit 1

    echo wget -nd "${SWURL}${SW}"
    wget -nd "${SWURL}${SW}" || exit 1

    BINUTILS=$DOWNLOADDIR/$SW
fi

# 0. creating the directory
echo mkdir -p $SRCDIR
mkdir -p $SRCDIR || exit 1


# 1. setting the path
PATH=$PREFIX/bin:$PATH


# 2. Do it ...
case $SWPKG in

    binutils)

    echo tar -xj -C $SRCDIR -f $BINUTILS
    tar -xj -C $SRCDIR -f $BINUTILS || exit 1

    BINUTILSSRCDIR=`ls -d $SRCDIR/binutils*`

    echo cd $BINUTILSSRCDIR
    cd $BINUTILSSRCDIR || exit 1

    echo $TOOLSDIR/patch.sh $BINUTILSSRCDIR $FILEDIR/patches
    $TOOLSDIR/patch.sh $BINUTILSSRCDIR $FILEDIR/patches || exit 1

    echo mkdir -p $BUILDDIR/binutils
    mkdir -p $BUILDDIR/binutils || exit 1

    echo cd $BUILDDIR/binutils
    cd $BUILDDIR/binutils || exit 1

    echo $BINUTILSSRCDIR/configure --target=$TARGET --prefix=$PREFIX --enable-shared
    $BINUTILSSRCDIR/configure --target=$TARGET --prefix=$PREFIX --enable-shared || exit 1

    echo make
    make -j 8 || exit 1

    echo make install
    make install || exit 1

    echo rm -rf $BUILDDIR/binutils $BINUTILSSRCDIR
    rm -rf $BUILDDIR/binutils $BINUTILSSRCDIR || exit 1

    ;;

esac

case $SWPKG in

    canadian-binutils)

    echo tar -xj -C $SRCDIR -f $BINUTILS
    tar -xj -C $SRCDIR -f $BINUTILS || exit 1

    BINUTILSSRCDIR=`ls -d $SRCDIR/binutils*`

    echo cd $BINUTILSSRCDIR
    cd $BINUTILSSRCDIR || exit 1

    echo $TOOLSDIR/patch.sh $BINUTILSSRCDIR $FILEDIR/patches
    $TOOLSDIR/patch.sh $BINUTILSSRCDIR $FILEDIR/patches || exit 1

    echo mkdir -p $BUILDDIR/binutils
    mkdir -p $BUILDDIR/binutils || exit 1

    echo cd $BUILDDIR/binutils
    cd $BUILDDIR/binutils || exit 1
    
    echo "PATH=" $PATH

    echo $BINUTILSSRCDIR/configure --build=x86_64-pc-linux-gnu --host=i686-w64-mingw32 --target=$TARGET --prefix=$PREFIX  --enable-shared
    $BINUTILSSRCDIR/configure --build=x86_64-pc-linux-gnu --host=i686-w64-mingw32 --target=$TARGET --prefix=$PREFIX --enable-shared || exit 1

    echo make
    make -j 8 || exit 1

    echo make install
    make install || exit 1

    echo rm -rf $BUILDDIR/binutils $BINUTILSSRCDIR
    rm -rf $BUILDDIR/binutils $BINUTILSSRCDIR || exit 1

    ;;

esac

exit 0
