#!/bin/sh

TARGET=$1
PREFIX=$2
SWPKG=$3

case $SWPKG in

    minimal-gcc | gcc | canadian-minimal-gcc | canadian-gcc)

      SWURL="ftp://ftp.gnu.org/gnu/gcc/gcc-5.1.0/"
      SW="gcc-5.1.0.tar.bz2"
      ;;
esac

if test -z "$PREFIX"; then
    echo "Crosscompiler install script."
    echo "To install the target toolchain type the following command:"
    echo $0 " <TargetAch> <InstallDir> <SoftwarePackage>"
    echo
    echo "The software package can be one of these:"
    echo "[all] binutils minimal-gcc uclibc gcc gdb clean"
    echo "If the parameter is missing, we're taking [all] as default."
    exit 0
fi

echo "We're going to install the gcc in this directory: " $PREFIX
echo "for " $TARGET " Architecture"
echo

# the different paths
FILEDIR=`pwd`
SRCDIR=$PREFIX/src
BUILDDIR=$SRCDIR/build

# The tar archievs
GCC=`ls $DOWNLOADDIR/$SW`

if [[ $GCC = $DOWNLOADDIR/$SW ]];
then
    echo $GCC " already found"
else
    echo cd $DOWNLOADDIR
    cd $DOWNLOADDIR || exit 1

    echo wget -c -nd "${SWURL}${SW}"
    wget -c -nd "${SWURL}${SW}" || exit 1

    GCC=$DOWNLOADDIR/$SW
fi

# 0. creating the directory
echo mkdir -p $SRCDIR
mkdir -p $SRCDIR || exit 1


# 1. setting the path
PATH=$PREFIX/bin:$PATH


# 2. minimal gcc
case $SWPKG in

    canadian-minimal-gcc)

    echo tar -xj -C $SRCDIR -f $GCC
    tar -xj -C $SRCDIR -f $GCC || exit 1

    GCCSRCDIR=`ls -d $SRCDIR/gcc*`

    echo cd $SRCDIR
    cd $SRCDIR || exit 1

    echo $TOOLSDIR/patch.sh $GCCSRCDIR $FILEDIR/patches
    $TOOLSDIR/patch.sh $GCCSRCDIR $FILEDIR/patches || exit 1

    echo mkdir -p $BUILDDIR/gcc
    mkdir -p $BUILDDIR/gcc || exit 1

    echo cd $BUILDDIR/gcc
    cd $BUILDDIR/gcc || exit 1

    echo $GCCSRCDIR/configure --host=i686-w64-mingw32 --target=$TARGET --prefix=$PREFIX  --disable-shared --enable-static --with-mpc=$PREFIX --with-mpfr=$PREFIX --with-gmp=$PREFIX --disable-__cxa_atexit --disable-nls --disable-libssp --with-newlib --enable-languages=c
    $GCCSRCDIR/configure --host=i686-w64-mingw32 --target=$TARGET --prefix=$PREFIX  --disable-shared --enable-static --with-mpc=$PREFIX --with-mpfr=$PREFIX --with-gmp=$PREFIX --disable-__cxa_atexit --disable-nls --disable-libssp --with-newlib --enable-languages=c || exit 1

    # don't exit on error because of problem in libiberty
    echo make -j 8
    make -j 8

    echo make install 
    make install || exit 1

    echo rm -rf $BUILDDIR/gcc $GCCSRCDIR
    rm -rf $BUILDDIR/gcc $GCCSRCDIR || exit 1

    cd $FILEDIR || exit 1

    ;;

    canadian-gcc)

    echo tar -xj -C $SRCDIR -f $GCC
    tar -xj -C $SRCDIR -f $GCC || exit 1

    GCCSRCDIR=`ls -d $SRCDIR/gcc*`

    echo cd $SRCDIR
    cd $SRCDIR || exit 1

    echo $TOOLSDIR/patch.sh $GCCSRCDIR $FILEDIR/patches
    $TOOLSDIR/patch.sh $GCCSRCDIR $FILEDIR/patches || exit 1

    echo mkdir -p $BUILDDIR/gcc
    mkdir -p $BUILDDIR/gcc || exit 1

    echo cd $BUILDDIR/gcc
    cd $BUILDDIR/gcc || exit 1

    cp -t  $BUILDDIR/gcc/arm-eabi/libstdc++-v3/include /usr/i686-w64-mingw32/usr/include/fenv.h
    cp -t  $BUILDDIR/gcc/arm-eabi/libstdc++-v3/include /usr/i686-w64-mingw32/usr/include/_mingw.h

    cp -t  $BUILDDIR/gcc/arm-eabi/thumb/libstdc++-v3/include /usr/i686-w64-mingw32/usr/include/fenv.h
    cp -t  $BUILDDIR/gcc/arm-eabi/thumb/libstdc++-v3/include /usr/i686-w64-mingw32/usr/include/_mingw.h

    cp -t  $BUILDDIR/gcc/arm-eabi/fpu/libstdc++-v3/include /usr/i686-w64-mingw32/usr/include/fenv.h
    cp -t  $BUILDDIR/gcc/arm-eabi/fpu/libstdc++-v3/include /usr/i686-w64-mingw32/usr/include/_mingw.h

    echo $GCCSRCDIR/configure  --host=i686-w64-mingw32 --target=$TARGET --prefix=$PREFIX --disable-shared --enable-static --with-mpc=$PREFIX --with-mpfr=$PREFIX --with-gmp=$PREFIX --disable-__cxa_atexit --disable-nls --disable-libssp --with-newlib --enable-languages=c,c++
    $GCCSRCDIR/configure --host=i686-w64-mingw32 --target=$TARGET --prefix=$PREFIX --disable-shared --enable-static --with-mpc=$PREFIX --with-mpfr=$PREFIX --with-gmp=$PREFIX --disable-__cxa_atexit --disable-nls --disable-libssp --with-newlib --enable-languages=c,c++ || exit 1

    # don't exit on error because of problem in libiberty
    echo make -j 8
    make -j 8 || exit 1

    echo make install
    make install || exit 1

    echo rm -rf $BUILDDIR/gcc $GCCSRCDIR
    rm -rf $BUILDDIR/gcc $GCCSRCDIR || exit 1

    cd $FILEDIR || exit 1

    ;;

    minimal-gcc)

    echo tar -xj -C $SRCDIR -f $GCC
    tar -xj -C $SRCDIR -f $GCC || exit 1

    GCCSRCDIR=`ls -d $SRCDIR/gcc*`

    echo cd $SRCDIR
    cd $SRCDIR || exit 1

    echo $TOOLSDIR/patch.sh $GCCSRCDIR $FILEDIR/patches
    $TOOLSDIR/patch.sh $GCCSRCDIR $FILEDIR/patches || exit 1

    echo mkdir -p $BUILDDIR/gcc
    mkdir -p $BUILDDIR/gcc || exit 1

    echo cd $BUILDDIR/gcc
    cd $BUILDDIR/gcc || exit 1

    echo $GCCSRCDIR/configure --target=$TARGET --prefix=$PREFIX --disable-__cxa_atexit --disable-nls --disable-libssp --with-newlib --enable-languages=c
    $GCCSRCDIR/configure --target=$TARGET --prefix=$PREFIX --disable-__cxa_atexit --disable-nls --disable-libssp --with-newlib --enable-languages=c || exit 1

    # don't exit on error because of problem in libiberty
    echo make -j 8
    make -j 8

    echo make install
    make install || exit 1

    echo rm -rf $BUILDDIR/gcc $GCCSRCDIR
    rm -rf $BUILDDIR/gcc $GCCSRCDIR || exit 1

    cd $FILEDIR || exit 1

    ;;

    gcc)

    echo tar -xj -C $SRCDIR -f $GCC
    tar -xj -C $SRCDIR -f $GCC || exit 1

    GCCSRCDIR=`ls -d $SRCDIR/gcc*`

    echo cd $SRCDIR
    cd $SRCDIR || exit 1

    echo $TOOLSDIR/patch.sh $GCCSRCDIR $FILEDIR/patches
    $TOOLSDIR/patch.sh $GCCSRCDIR $FILEDIR/patches || exit 1

    echo mkdir -p $BUILDDIR/gcc
    mkdir -p $BUILDDIR/gcc || exit 1

    echo cd $BUILDDIR/gcc
    cd $BUILDDIR/gcc || exit 1

    echo $GCCSRCDIR/configure --target=$TARGET --prefix=$PREFIX --disable-__cxa_atexit --disable-nls --disable-libssp --with-newlib --enable-languages=c,c++
    $GCCSRCDIR/configure --target=$TARGET --prefix=$PREFIX --disable-__cxa_atexit --disable-nls --disable-libssp --with-newlib --enable-languages=c,c++ || exit 1

    # don't exit on error because of problem in libiberty
    echo make -j 3
    make -j 3

    echo make install
    make install || exit 1

    echo rm -rf $BUILDDIR/gcc $GCCSRCDIR
    rm -rf $BUILDDIR/gcc $GCCSRCDIR || exit 1

    cd $FILEDIR || exit 1

    ;;

esac


exit 0
