#!/bin/sh

TARGET=$1
PREFIX=$2
SWPKG=$3

#SWURL="ftp://sourceware.org/pub/insight/releases/"
SWURL="http://ftp.gnu.org/gnu/gdb/"
SW="gdb-7.9.tar.gz"

if test -z "$PREFIX"; then
    echo "Crosscompiler install script."
    echo "To install the target toolchain type the following command:"
    echo $0 " <TargetAch> <InstallDir> <SoftwarePackage>"
    echo
    echo "The software package can be one of these:"
    echo "[all] binutils minimal-gcc libc gcc gdb clean"
    echo "If the parameter is missing, we're taking [all] as default."
    exit 0
fi

echo "We're going to install the binutils in this directory: " $PREFIX
echo "for " $TARGET " Architecture"
echo

# the different paths
FILEDIR=`pwd`
SRCDIR=$PREFIX/src
BUILDDIR=$SRCDIR/build

# The tar archievs
GDB=`ls $DOWNLOADDIR/$SW`

if [[ $GDB = $DOWNLOADDIR/$SW ]];
then
    echo $GDB " already found"
else
    echo cd $DOWNLOADDIR
    cd $DOWNLOADDIR || exit 1

    echo wget -nd "${SWURL}${SW}"
    wget -nd "${SWURL}${SW}" || exit 1

    GDB=$DOWNLOADDIR/$SW
fi

# 0. creating the directory
echo mkdir -p $SRCDIR
mkdir -p $SRCDIR || exit 1


# 1. setting the path
PATH=$PREFIX/bin:$PATH


# 2. Do it ...
case $SWPKG in

    gdb)

    echo tar -xz -C $SRCDIR -f $GDB
    tar -xz -C $SRCDIR -f $GDB || exit 1

    echo mkdir -p $BUILDDIR/gdb
    mkdir -p $BUILDDIR/gdb || exit 1

    echo cd $BUILDDIR/gdb
    cd $BUILDDIR/gdb || exit 1

    GDBSRCDIR=`ls -d $SRCDIR/gdb*`

    echo $GDBSRCDIR/configure --target=$TARGET --prefix=$PREFIX --disable-werror
    $GDBSRCDIR/configure --target=$TARGET --prefix=$PREFIX --disable-werror || exit 1

    echo make
    make -j 8 || exit 1

    echo make install
    make install || exit 1

    echo rm -rf $BUILDDIR/gdb $GDBSRCDIR
    rm -rf $BUILDDIR/gdb $GDBSRCDIR || exit 1

    cd $FILEDIR || exit 1

    ;;

esac


case $SWPKG in

    canadian-gdb)

    echo tar -xz -C $SRCDIR -f $GDB
    tar -xz -C $SRCDIR -f $GDB || exit 1

    echo mkdir -p $BUILDDIR/gdb
    mkdir -p $BUILDDIR/gdb || exit 1

    echo cd $BUILDDIR/gdb
    cd $BUILDDIR/gdb || exit 1

    GDBSRCDIR=`ls -d $SRCDIR/gdb*`

    echo $GDBSRCDIR/configure --host=i686-w64-mingw32 --target=$TARGET --prefix=$PREFIX --disable-werror
    $GDBSRCDIR/configure --host=i686-w64-mingw32 --target=$TARGET --prefix=$PREFIX --disable-werror || exit 1

    echo make
    make -j 8 || exit 1

    echo make install
    make install || exit 1

    echo rm -rf $BUILDDIR/gdb $GDBSRCDIR
    rm -rf $BUILDDIR/gdb $GDBSRCDIR || exit 1

    cd $FILEDIR || exit 1

    ;;

esac

exit 0
