#!/bin/sh

TARGET=$1
PREFIX=$2
SWPKG=$3
CANADIAN=$4

WIN32TOOLCHAIN=/opt/uC/i686-w64-mingw32-gcc-4.8.3-binutils-2.24.0/bin
export WIN32HOST=i686-w64-mingw32

if test -z "$PREFIX"; then
	echo "Crosscompiler install script."
	echo "To install the target toolchain type the following command:"
	echo $0 " <TargetAch> <InstallDir> <SoftwarePackage> [canadian]"
	echo
	echo "The software package can be one of these:"
	echo "[all] binutils minimal-gcc (linux-header) libc gcc gdb clean"
	echo "If the parameter is missing, we're taking [all] as default."
	exit
fi

# Check the target architecture
if [ ! `ls -d arch/* | grep "/${TARGET}$"` ];
then
    echo "Error: Unknown target ${TARGET}"
    exit 1
fi

echo "We're going to install the target toolchain in this directory: " $PREFIX
echo "for " $TARGET " Architecture"
echo

# test that we have write permissions to the install dir
mkdir -p ${PREFIX}/${TARGET}
touch ${PREFIX}/${TARGET}/test-if-write
if [ ! -f ${PREFIX}/${TARGET}/test-if-write ]; then
    echo "You don't appear to have write permissions to ${PREFIX}/${TARGET}."
    echo "You must fix that before continuing."
    exit 1
fi

# the different paths
FILEDIR=`pwd`
export TOOLSDIR=$FILEDIR/tools
export DOWNLOADDIR=$FILEDIR/download
BINDIR=$PREFIX/bin
SRCDIR=$PREFIX/src
BUILDDIR=$SRCDIR/build

# 0. creating the directory
echo mkdir -p $DOWNLOADDIR
mkdir -p $DOWNLOADDIR || exit 1     

echo mkdir -p $BINDIR
mkdir -p $BINDIR || exit 1

echo mkdir -p $SRCDIR
mkdir -p $SRCDIR || exit 1


# 1. setting the path
export PATH=$PREFIX/bin:$PATH
if [ "$CANADIAN" == "canadian" ]; then
    SWPKG=canadian-$SWPKG
    export PATH=$WIN32TOOLCHAIN:$PATH
fi

# 2. binutils
case $SWPKG in

    all | canadian-all | binutils | canadian-binutils)

	echo cd ${FILEDIR}/arch/${TARGET}/binutils
	cd ${FILEDIR}/arch/${TARGET}/binutils || exit 1

	echo ./binutils.sh ${TARGET} ${PREFIX} binutils
	./binutils.sh ${TARGET} ${PREFIX} binutils || exit 1

	;;

esac

# 2. canadian binutils
case $SWPKG in

    canadian-all | canadian-binutils)

    echo cd ${FILEDIR}/arch/${TARGET}/binutils
    cd ${FILEDIR}/arch/${TARGET}/binutils || exit 1

    echo ./binutils.sh ${TARGET} ${PREFIX} canadian-binutils
    ./binutils.sh ${TARGET} ${PREFIX} canadian-binutils || exit 1

    ;;

esac


# minimal gcc
case $SWPKG in

    all | canadian-all | minimal-gcc | canadian-minimal-gcc)

    echo cd ${FILEDIR}/arch/${TARGET}/gcc
    cd ${FILEDIR}/arch/${TARGET}/gcc || exit 1

    echo ./gcc.sh ${TARGET} ${PREFIX} minimal-gcc
    ./gcc.sh ${TARGET} ${PREFIX} minimal-gcc || exit 1

    ;;

esac


# canadian minimal gcc
#case $SWPKG in
#
#    canadian-all | canadian-minimal-gcc)
#
#    echo cd ${FILEDIR}/arch/${TARGET}/gcc
#    cd ${FILEDIR}/arch/${TARGET}/gcc || exit 1
#
#    echo ./gmp.sh ${TARGET} ${PREFIX} gmp
#    ./gmp.sh ${TARGET} ${PREFIX} gmp || exit 1
#
#    echo ./mpfr.sh ${TARGET} ${PREFIX} mpfr
#    ./mpfr.sh ${TARGET} ${PREFIX} mpfr || exit 1
#
#    echo ./mpc.sh ${TARGET} ${PREFIX} mpc
#    ./mpc.sh ${TARGET} ${PREFIX} mpc || exit 1
#
#    echo ./gcc.sh ${TARGET} ${PREFIX} canadian-minimal-gcc
#    ./gcc.sh ${TARGET} ${PREFIX} canadian-minimal-gcc || exit 1
#
#    ;;
#
#esac


# 4a. linux-header
#case $SWPKG in
#
#    all | linux-header)
#
#    echo cd ${FILEDIR}/arch/${TARGET}/linux
#    cd ${FILEDIR}/arch/${TARGET}/linux || exit 1
#
#    echo ./linux.sh ${TARGET} ${PREFIX} linux-header
#    ./linux.sh ${TARGET} ${PREFIX} linux-header || exit 1
#
#	;;
#
#esac


# 4b. libc
case $SWPKG in

    all | canadian-all | libc | canadian-libc)

    echo cd ${FILEDIR}/arch/${TARGET}/libc
    cd ${FILEDIR}/arch/${TARGET}/libc || exit 1

    echo ./libc.sh ${TARGET} ${PREFIX} libc
    ./libc.sh ${TARGET} ${PREFIX} libc || exit 1

    ;;

esac

#case $SWPKG in
#
#    canadian-all | canadian-libc)
#
#    echo cd ${FILEDIR}/arch/${TARGET}/libc
#    cd ${FILEDIR}/arch/${TARGET}/libc || exit 1
#
#    echo ./libc.sh ${TARGET} ${PREFIX} canadian-libc
#    ./libc.sh ${TARGET} ${PREFIX} canadian-libc || exit 1
#
#    ;;
#
#esac


# 5. gcc
case $SWPKG in

    canadian-all | canadian-gcc)

    echo cd ${FILEDIR}/arch/${TARGET}/gcc
    cd ${FILEDIR}/arch/${TARGET}/gcc || exit 1

    echo ./gmp.sh ${TARGET} ${PREFIX} gmp
    ./gmp.sh ${TARGET} ${PREFIX} gmp || exit 1

    echo ./mpfr.sh ${TARGET} ${PREFIX} mpfr
    ./mpfr.sh ${TARGET} ${PREFIX} mpfr || exit 1

    echo ./mpc.sh ${TARGET} ${PREFIX} mpc
    ./mpc.sh ${TARGET} ${PREFIX} mpc || exit 1

    echo ./gcc.sh ${TARGET} ${PREFIX} canadian-gcc
    ./gcc.sh ${TARGET} ${PREFIX} canadian-gcc || exit 1

    ;;

esac


# 6. gcc
case $SWPKG in

    all | gcc)

    echo cd ${FILEDIR}/arch/${TARGET}/gcc
    cd ${FILEDIR}/arch/${TARGET}/gcc || exit 1

    echo ./gcc.sh ${TARGET} ${PREFIX} gcc
    ./gcc.sh ${TARGET} ${PREFIX} gcc || exit 1

	;;

esac


# 6. GDB
case $SWPKG in

    all | gdb)

    echo cd ${FILEDIR}/arch/${TARGET}/gdb
    cd ${FILEDIR}/arch/${TARGET}/gdb || exit 1

    echo ./gdb.sh ${TARGET} ${PREFIX} gdb
    ./gdb.sh ${TARGET} ${PREFIX} gdb || exit 1

	;;

    canadian-all | canadian-gdb)

    echo cd ${FILEDIR}/arch/${TARGET}/gdb
    cd ${FILEDIR}/arch/${TARGET}/gdb || exit 1

    echo ./gdb.sh ${TARGET} ${PREFIX} canadian-gdb
    ./gdb.sh ${TARGET} ${PREFIX} canadian-gdb || exit 1

    ;;

esac


# Installing make
case $SWPKG in

    all | tools | make)

    echo cd ${FILEDIR}/arch/common/make
    cd ${FILEDIR}/arch/common/make || exit 1

    echo ./make.sh ${TARGET} ${PREFIX} make
    ./make.sh ${TARGET} ${PREFIX} make || exit 1

    ;;

    canadian-all | canadian-tools | canadian-make)

    echo cd ${FILEDIR}/arch/common/make
    cd ${FILEDIR}/arch/common/make || exit 1

    echo ./make.sh ${TARGET} ${PREFIX} canadian-make
    ./make.sh ${TARGET} ${PREFIX} canadian-make || exit 1

    ;;

esac


# Installing libusb
case $SWPKG in

    canadian-all | canadian-avarice | canadian-avrdude | canadian-libusb)

    echo cd ${FILEDIR}/arch/common/libusb
    cd ${FILEDIR}/arch/common/libusb || exit 1

    echo ./libusb.sh ${TARGET} ${PREFIX} canadian-libusb
    ./libusb.sh ${TARGET} ${PREFIX} canadian-libusb || exit 1

    ;;

esac


# Installing avarice and avrdude
case $TARGET in

    avr)
        case $SWPKG in

            all | canadian-all | tools | canadian-tools | avarice | canadian-avarice)

            echo cd ${FILEDIR}/arch/avr/avarice
            cd ${FILEDIR}/arch/avr/avarice || exit 1

            echo ./avarice.sh ${TARGET} ${PREFIX} $SWPKG
            ./avarice.sh ${TARGET} ${PREFIX} $SWPKG || exit 1

            ;;

        esac

        case $SWPKG in

            canadian-all | all | tools | canadian-avrdude | avrdude)

            echo cd ${FILEDIR}/arch/avr/avrdude
            cd ${FILEDIR}/arch/avr/avrdude || exit 1

            echo ./avrdude.sh ${TARGET} ${PREFIX} $SWPKG
            ./avrdude.sh ${TARGET} ${PREFIX} $SWPKG || exit 1

            ;;

        esac
    ;;
esac


# 7. cleaning
case $SWPKG in

    all | clean)

   echo rm -rf $SRCDIR
   rm -rf $SRCDIR

    ;;

    canadian-all | canadian-clean)

    echo rm -rf $SRCDIR
    rm -rf $SRCDIR
    
    echo "find $BINDIR -name '*.exe' | sed 's/.exe$//' | xargs ls"
    find $BINDIR -name '*.exe' | sed 's/.exe$//' | xargs rm

    ;;

esac


# 8. permissions
#echo chown -R root:root $PREFIX
#chown -R root:root $PREFIX || exit


exit 0
